#include "tulip/WithParameter.h"
#include "tulip/Reflect.h"
StructDef WithParameter::getParameters(){return parameters;}
